==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/7f/7f30f80d898f73ce605c053bfcfc2d7f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png */
class __TwigTemplate_03b2b35d190c4ac6ba373902a02caf41 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000h\000\000\000J\000\000\000`\000\000\000PLTE\000\000\000FFFFFFFFFFFFtttUUUFFF2Ϡ\000\000\000BtRNS\000\00000``Pp @ϰ`Eݐܖ!)fߋDJ~p\000\000\tIDATx^n0ab[S6{;E¹W\000b48#Q
#U/F&5Óz)vG{= 8`>:Dv\"X)8`Bg@aL`#*UKf6낶[TZv@6e\000~&f9pÇ͢);tPTWZm=--2m@vnAW21a]7szر^z8V8
j/%H/L\\'N+LLua7 Re=:>BN:TDVE6U~ΘйHX:A\\|x㽨d,(7*ghzt#brT';т\$}kъJ
J_ނ\tXWwuʻp]^\"AOn.ťu|݈s
ݷ?~U󖪊1>HoeN\"A!8
\"CA\"BA\"CJu<a+\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/7f/7f30f80d898f73ce605c053bfcfc2d7f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png */
class __TwigTemplate_03b2b35d190c4ac6ba373902a02caf41 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000h\000\000\000J\000\000\000`\000\000\000PLTE\000\000\000FFFFFFFFFFFFtttUUUFFF2Ϡ\000\000\000BtRNS\000\00000``Pp @ϰ`Eݐܖ!)fߋDJ~p\000\000\tIDATx^n0ab[S6{;E¹W\000b48#Q
#U/F&5Óz)vG{= 8`>:Dv\"X)8`Bg@aL`#*UKf6낶[TZv@6e\000~&f9pÇ͢);tPTWZm=--2m@vnAW21a]7szر^z8V8
j/%H/L\\'N+LLua7 Re=:>BN:TDVE6U~ΘйHX:A\\|x㽨d,(7*ghzt#brT';т\$}kъJ
J_ނ\tXWwuʻp]^\"AOn.ťu|݈s
ݷ?~U󖪊1>HoeN\"A!8
\"CA\"BA\"CJu<a+\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite@2x.png");
    }
}
